@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2018-2021 Matthias Klumpp <matthias@tenstral.net>
+# Copyright (C) 2018-2022 Matthias Klumpp <matthias@tenstral.net>
 #
 # Licensed under the GNU Lesser General Public License Version 3
 #
@@ -19,19 +19,28 @@
 
 import os
 import json
-import subprocess
 import shutil
+import typing as T
+import subprocess
 from pathlib import Path
 from contextlib import contextmanager
-from typing import Optional
-from .utils import temp_dir, print_header, print_section, format_filesize, \
-    print_info, print_error, print_warn, listify
-from .utils.misc import maybe_remove, safe_copy
-from .utils.env import ensure_root, get_random_free_uid_gid, get_owner_uid_gid
-from .utils.command import safe_run
-from .utils.zstd_tar import compress_directory, decompress_tarball, ensure_tar_zstd
-from .nspawn import nspawn_run_helper_persist, nspawn_run_persist
+
+from .utils import (
+    listify,
+    temp_dir,
+    print_info,
+    print_warn,
+    print_error,
+    print_header,
+    print_section,
+    format_filesize,
+)
+from .nspawn import nspawn_run_persist, nspawn_run_helper_persist
 from .aptcache import APTCache
+from .utils.env import ensure_root, get_owner_uid_gid, get_random_free_uid_gid
+from .utils.misc import safe_copy, maybe_remove, rmtree_mntsafe
+from .utils.command import safe_run
+from .utils.zstd_tar import ensure_tar_zstd, compress_directory, decompress_tarball
 
 
 def debootstrap_version():
@@ -51,8 +60,7 @@ class OSBase:
     Describes an OS base registered with debspawn
     '''
 
-    def __init__(self, gconf, suite, arch, variant=None, *,
-                 base_suite=None, custom_name=None, cachekey=None):
+    def __init__(self, gconf, suite, arch, variant=None, *, base_suite=None, custom_name=None, cachekey=None):
         self._gconf = gconf
         self._suite = suite
         self._base_suite = base_suite
@@ -81,8 +89,8 @@ class OSBase:
         ensure_tar_zstd()
 
     def _make_name(self):
-        ''' Configure a unique-ish name based on user defined data,
-        and tweak the custom name and suite values to match. '''
+        '''Configure a unique-ish name based on user defined data,
+        and tweak the custom name and suite values to match.'''
 
         if self._custom_name and not self._suite:
             # if we have a custom name but no suite name, the custom name is treated
@@ -109,7 +117,7 @@ class OSBase:
             return '{}-{}'.format(self._suite, self._arch)
 
     def _custom_name_parameter_check(self):
-        ''' Read parameters in case a custom name was passed, and perform basic sanity checks. '''
+        '''Read parameters in case a custom name was passed, and perform basic sanity checks.'''
         import sys
 
         if self._parameters_checked:
@@ -132,20 +140,28 @@ class OSBase:
                 self._suite = c_suite
 
             if self.suite != c_suite:
-                print_error('Expected suite name "{}" for image "{}", but got "{}" instead.'.format(
-                    cdata.get('Suite'), self.name, self.suite))
+                print_error(
+                    'Expected suite name "{}" for image "{}", but got "{}" instead.'.format(
+                        cdata.get('Suite'), self.name, self.suite
+                    )
+                )
                 sys.exit(1)
             c_arch = cdata.get('Architecture', self.arch)
             c_variant = cdata.get('Variant', self.variant)
 
             if self.arch and self.arch != c_arch:
-                print_warn(('Expected architecture "{}" for image "{}", but got "{}" instead. '
-                            'Using expected value.').format(
-                                c_arch, self.name, self.arch))
+                print_warn(
+                    (
+                        'Expected architecture "{}" for image "{}", but got "{}" instead. '
+                        'Using expected value.'
+                    ).format(c_arch, self.name, self.arch)
+                )
             if self.variant and self.variant != c_variant:
-                print_warn(('Expected variant "{}" for image "{}", but got "{}" instead. '
-                            'Using expected value.').format(
-                                c_variant, self.name, self.variant))
+                print_warn(
+                    (
+                        'Expected variant "{}" for image "{}", but got "{}" instead. ' 'Using expected value.'
+                    ).format(c_variant, self.name, self.variant)
+                )
             self._arch = c_arch
             self._variant = c_variant
         self._parameters_checked = True
@@ -234,12 +250,15 @@ class OSBase:
         program with an error code in case it does not.
         '''
         import sys
+
         if not self._load_existent():
-            print_error('The container image for "{}" does not exist. Please create it first.'.format(self.name))
+            print_error(
+                'The container image for "{}" does not exist. Please create it first.'.format(self.name)
+            )
             sys.exit(3)
 
     def _load_existent(self) -> bool:
-        ''' Check if image exists, and if so load some essential data and return True. '''
+        '''Check if image exists, and if so load some essential data and return True.'''
         # ensure the set config values are sane if the user is using a custom container name
         if self._custom_name:
             self._custom_name_parameter_check()
@@ -248,7 +267,7 @@ class OSBase:
     def new_nspawn_machine_name(self):
         import platform
         from random import choice
-        from string import ascii_lowercase, digits
+        from string import digits, ascii_lowercase
 
         nid = ''.join(choice(ascii_lowercase + digits) for _ in range(4))
 
@@ -259,18 +278,19 @@ class OSBase:
         uniq_suffix = '{}-{}'.format(self.name, nid)
         if len(uniq_suffix) > 48:
             uniq_suffix = ''.join(choice(ascii_lowercase + digits) for _ in range(12))
-        node_name_prefix = platform.node()[:63 - len(uniq_suffix)]
+        node_name_prefix = platform.node()[: 63 - len(uniq_suffix)]
 
         return '{}-{}'.format(node_name_prefix, uniq_suffix)
 
-    def _write_config_json(self, mirror, components, extra_suites, extra_source_lines):
+    def _write_config_json(
+        self, mirror, components, extra_suites, extra_source_lines, *, allow_recommends: bool, with_init: bool
+    ):
         '''
         Create configuration file for this container base image
         '''
 
         print_info('Saving configuration settings.')
-        data = {'Suite': self.suite,
-                'Architecture': self.arch}
+        data: T.Dict[str, T.Union[str, bool]] = {'Suite': self.suite, 'Architecture': self.arch}
         if self.variant:
             data['Variant'] = self.variant
         if mirror:
@@ -281,13 +301,17 @@ class OSBase:
             data['ExtraSuites'] = extra_suites
         if extra_source_lines:
             data['ExtraSourceLines'] = extra_source_lines
+        if allow_recommends:
+            data['AllowRecommends'] = True
+        if with_init:
+            data['IncludesInit'] = True
 
         with open(self.get_config_location(), 'wt') as f:
             f.write(json.dumps(data, sort_keys=True, indent=4))
             f.write('\n')
 
     def _clear_image_tree(self, image_dir):
-        ''' Clear files from a directory tree that we don't want in the tarball. '''
+        '''Clear files from a directory tree that we don't want in the tarball.'''
 
         if os.path.ismount(image_dir):
             print_warn('Preparing OS tree for compression, but /dev is still mounted.')
@@ -300,7 +324,7 @@ class OSBase:
                     os.remove(fname)
 
     def _remove_unwanted_files(self, instance_dir):
-        ''' Delete unwanted files from a base image '''
+        '''Delete unwanted files from a base image'''
 
         # drop resolv.conf: Some OSes set this to a symlink, which will lead to nowhere
         # in the container and may cause issues when bindmounting over it
@@ -315,8 +339,13 @@ class OSBase:
         maybe_remove(os.path.join(instance_dir, 'var', 'log', 'lastlog'))
         maybe_remove(os.path.join(instance_dir, 'var', 'log', 'faillog'))
 
+        # drop APT package caches, we do not want them in the tarballs
+        apt_pkg_cache_dir = os.path.join(instance_dir, 'var', 'cache', 'apt', 'archives')
+        if os.path.isdir(apt_pkg_cache_dir):
+            rmtree_mntsafe(apt_pkg_cache_dir, ignore_errors=True)
+
     def _setup_apt_proxy(self, instance_dir):
-        ''' Setup APT proxy configuration.
+        '''Setup APT proxy configuration.
         APT needs special treatment even in the container to work with a company proxy (yuck!),
         so we do this here so the user does not need to care about it.
         '''
@@ -337,11 +366,18 @@ class OSBase:
             if https_proxy:
                 f.write('Acquire::https::Proxy "{}";\n'.format(https_proxy))
 
-    def _create_internal(self, mirror=None, components=None,
-                         extra_suites: list[str] = None, extra_source_lines: str = None,
-                         allow_recommends: bool = False,
-                         show_header: bool = True):
-        ''' Create new container base image (internal method) '''
+    def _create_internal(
+        self,
+        mirror=None,
+        components=None,
+        *,
+        extra_suites: list[str] = None,
+        extra_source_lines: str = None,
+        allow_recommends: bool = False,
+        with_init: bool = False,
+        show_header: bool = True,
+    ):
+        '''Create new container base image (internal method)'''
 
         if self.exists():
             print_error('An image already exists for this configuration. Can not create a new one.')
@@ -361,10 +397,14 @@ class OSBase:
             print('Custom name: {}'.format(self.name))
         print('Using mirror: {}'.format(mirror if mirror else 'default'))
         if self.variant:
-            print('variant: {}'.format(self.variant))
-        cmd = ['debootstrap',
-               '--arch={}'.format(self.arch),
-               '--include=python3-minimal,eatmydata']
+            print('Variant: {}'.format(self.variant))
+        if with_init:
+            print('Includes init: yes')
+
+        include_pkgs = ['python3-minimal', 'eatmydata']
+        if with_init:
+            include_pkgs.append('systemd-sysv')
+        cmd = ['debootstrap', '--arch={}'.format(self.arch), '--include=' + ','.join(include_pkgs)]
         if components:
             cmd.append('--components={}'.format(','.join(components)))
         if self.variant:
@@ -404,7 +444,8 @@ class OSBase:
                         contents = f.read()
                         matches = re.findall(
                             'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\\(\\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+',
-                            contents)
+                            contents,
+                        )
                         if not matches:
                             print_error('Unable to detect default APT repository URL (no regex matches).')
                             return False
@@ -419,9 +460,11 @@ class OSBase:
                     components = ['main']
                 with open(sourceslist_fname, 'a') as f:
                     if self.has_base_suite:
-                        f.write('deb {mirror} {suite} {components}\n'.format(mirror=mirror,
-                                                                             suite=self.suite,
-                                                                             components=' '.join(components)))
+                        f.write(
+                            'deb {mirror} {suite} {components}\n'.format(
+                                mirror=mirror, suite=self.suite, components=' '.join(components)
+                            )
+                        )
 
                     if extra_suites:
                         f.write('\n')
@@ -429,9 +472,11 @@ class OSBase:
                             if esuite == self.suite or esuite == bootstrap_suite:
                                 # don't add existing suites multiple times
                                 continue
-                            f.write('deb {mirror} {esuite} {components}\n'.format(mirror=mirror,
-                                                                                  esuite=esuite,
-                                                                                  components=' '.join(components)))
+                            f.write(
+                                'deb {mirror} {esuite} {components}\n'.format(
+                                    mirror=mirror, esuite=esuite, components=' '.join(components)
+                                )
+                            )
 
                     if extra_source_lines:
                         f.write('\n')
@@ -449,6 +494,27 @@ class OSBase:
                     f.write('APT::Install-Recommends "0";\n')
                     f.write('APT::Install-Suggests "0";\n')
 
+            if with_init:
+                # if we are allowing to boot this container, add a passwordless root login
+                # hack so the user gets a root shell instead of a login prompt
+                getty_override_fname = os.path.join(
+                    tdir, 'etc', 'systemd', 'system', 'console-getty.service.d', 'autorootlogin.conf'
+                )
+                os.makedirs(os.path.dirname(getty_override_fname), exist_ok=True)
+                with open(getty_override_fname, 'w') as f:
+                    # fail immediately with a proper exit code when e.g. apt update fails,
+                    # so we can retry and don't silently use old packages
+                    # (only available with newer APT versions)
+                    f.write(
+                        (
+                            '[Service]\n'
+                            'ExecStart=\n'
+                            'ExecStartPre=-/usr/bin/sed -i \'/pam_loginuid.so/d\' /etc/pam.d/login\n'
+                            'ExecStart=-/sbin/agetty --autologin root --noclear '
+                            '--keep-baud - 115200,38400,9600 $TERM\n'
+                        )
+                    )
+
             # delete unwanted files, especially resolv.conf as a broken one will
             # mess with the next step
             self._remove_unwanted_files(tdir)
@@ -457,10 +523,12 @@ class OSBase:
             self._setup_apt_proxy(tdir)
 
             print_section('Configure')
-            if nspawn_run_helper_persist(self, tdir,
-                                         self.new_nspawn_machine_name(),
-                                         '--update',
-                                         build_uid=self._builder_uid) != 0:
+            if (
+                nspawn_run_helper_persist(
+                    self, tdir, self.new_nspawn_machine_name(), '--update', build_uid=self._builder_uid
+                )
+                != 0
+            ):
                 return False
 
             # drop any unwanted files (again) before building the tarball
@@ -472,33 +540,50 @@ class OSBase:
 
         # store configuration settings, so we can later recreate this tarball
         # or just display information about it
-        self._write_config_json(mirror, components, extra_suites, extra_source_lines)
+        self._write_config_json(
+            mirror,
+            components,
+            extra_suites,
+            extra_source_lines,
+            allow_recommends=allow_recommends,
+            with_init=with_init,
+        )
 
         return True
 
-    def create(self, mirror: str = None, components: list[str] = None, *,
-               extra_suites: list[str] = None, extra_source_lines: str = None,
-               allow_recommends: bool = False):
-        ''' Create new container base image (internal method) '''
+    def create(
+        self,
+        mirror: str = None,
+        components: list[str] = None,
+        *,
+        extra_suites: list[str] = None,
+        extra_source_lines: str = None,
+        allow_recommends: bool = False,
+        with_init: bool = False,
+    ):
+        '''Create new container base image (internal method)'''
         ensure_root()
 
         if self.exists():
             print_error('This configuration has already been created. You can only delete or update it.')
             return False
 
-        ret = self._create_internal(mirror=mirror,
-                                    components=components,
-                                    extra_suites=extra_suites,
-                                    extra_source_lines=extra_source_lines,
-                                    allow_recommends=allow_recommends,
-                                    show_header=True)
+        ret = self._create_internal(
+            mirror=mirror,
+            components=components,
+            extra_suites=extra_suites,
+            extra_source_lines=extra_source_lines,
+            allow_recommends=allow_recommends,
+            with_init=with_init,
+            show_header=True,
+        )
         if ret:
             print_info('Done.')
 
         return ret
 
     def delete(self):
-        ''' Remove container base image '''
+        '''Remove container base image'''
         ensure_root()
 
         if not self._load_existent():
@@ -541,7 +626,7 @@ class OSBase:
             yield tdir, self.new_nspawn_machine_name()
 
     def make_instance_permanent(self, instance_dir):
-        ''' Add changes done in the current instance to the main tarball of this OS tree, replacing it. '''
+        '''Add changes done in the current instance to the main tarball of this OS tree, replacing it.'''
 
         # remove unwanted files from the tarball
         self._clear_image_tree(instance_dir)
@@ -560,12 +645,14 @@ class OSBase:
 
         tar_size = os.path.getsize(tarball_name)
         if self._cachekey:
-            print_info('New compressed tarball size (for {}) is {}'.format(self._cachekey, format_filesize(tar_size)))
+            print_info(
+                'New compressed tarball size (for {}) is {}'.format(self._cachekey, format_filesize(tar_size))
+            )
         else:
             print_info('New compressed tarball size is {}'.format(format_filesize(tar_size)))
 
     def update(self):
-        ''' Update container base image '''
+        '''Update container base image'''
         ensure_root()
 
         if not self._load_existent():
@@ -579,10 +666,16 @@ class OSBase:
             self._copy_helper_script(instance_dir)
 
             print_section('Update')
-            if nspawn_run_helper_persist(self, instance_dir,
-                                         self.new_nspawn_machine_name(),
-                                         '--update',
-                                         build_uid=self._builder_uid) != 0:
+            if (
+                nspawn_run_helper_persist(
+                    self,
+                    instance_dir,
+                    self.new_nspawn_machine_name(),
+                    '--update',
+                    build_uid=self._builder_uid,
+                )
+                != 0
+            ):
                 return False
 
             # drop unwanted files from the image
@@ -601,7 +694,7 @@ class OSBase:
         return True
 
     def recreate(self):
-        ''' Recreate a container base image '''
+        '''Recreate a container base image'''
         ensure_root()
 
         if not self._load_existent():
@@ -610,14 +703,16 @@ class OSBase:
 
         config_fname = self.get_config_location()
         if not os.path.isfile(config_fname):
-            print_error('Can not recreate "{}": Unable to find configuration data for this image.'.format(self.name))
+            print_error(
+                'Can not recreate "{}": Unable to find configuration data for this image.'.format(self.name)
+            )
             return False
 
         print_header('Recreating container image')
 
         # read configuration data
         with open(config_fname, 'rt') as f:
-            cdata = json.loads(f.read())
+            cdata: T.Dict[str, T.Union[str, bool]] = json.loads(f.read())
             self._suite = cdata.get('Suite', self.suite)
             self._arch = cdata.get('Architecture', self.arch)
             self._variant = cdata.get('Variant', self.variant)
@@ -626,6 +721,7 @@ class OSBase:
             extra_suites = cdata.get('ExtraSuites', [])
             extra_source_lines = cdata.get('ExtraSourceLines')
             allow_recommends = cdata.get('AllowRecommends', False)
+            with_init = cdata.get('IncludesInit', False)
 
         print_section('Deleting cache')
         cache_size = self._aptcache.clear()
@@ -644,12 +740,15 @@ class OSBase:
 
         # ty to create the tarball again
         try:
-            ret = self._create_internal(mirror=mirror,
-                                        components=components,
-                                        extra_suites=extra_suites,
-                                        extra_source_lines=extra_source_lines,
-                                        allow_recommends=allow_recommends,
-                                        show_header=False)
+            ret = self._create_internal(
+                mirror=mirror,
+                components=components,
+                extra_suites=extra_suites,
+                extra_source_lines=extra_source_lines,
+                allow_recommends=allow_recommends,
+                with_init=with_init,
+                show_header=False,
+            )
         except Exception as e:
             print_error('Error while trying to create image: {}'.format(str(e)))
             ret = False
@@ -673,27 +772,33 @@ class OSBase:
             print_info('Recreation failed.')
             return False
 
-    def login(self, persistent=False, allowed: list[str] = None):
-        ''' Interactive shell login into the container '''
+    def login(self, persistent=False, *, allowed: list[str] = None, boot: bool = False):
+        '''Interactive shell login into the container'''
         ensure_root()
 
         if not self._load_existent():
             print_info('Can not enter "{}": This configuration does not exist.'.format(self.name))
             return False
 
-        print_header('Login (persistent changes) for {}'.format(self.name)
-                     if persistent else 'Login for {}'.format(self.name))
+        print_header(
+            'Login (persistent changes) for {}'.format(self.name)
+            if persistent
+            else 'Login for {}'.format(self.name)
+        )
         with self.new_instance() as (instance_dir, _):
             # ensure helper script runner exists and is up to date
             self._copy_helper_script(instance_dir)
 
             # run an interactive shell in the new container
-            nspawn_run_persist(self,
-                               instance_dir,
-                               self.new_nspawn_machine_name(),
-                               '/srv',
-                               verbose=True,
-                               allowed=allowed)
+            nspawn_run_persist(
+                self,
+                instance_dir,
+                self.new_nspawn_machine_name(),
+                '/srv',
+                verbose=True,
+                allowed=allowed,
+                boot=boot,
+            )
 
             if persistent:
                 print_section('Recreating tarball')
@@ -704,7 +809,7 @@ class OSBase:
         print_info('Done.')
         return True
 
-    def retrieve_artifacts(self, src_dir: str, dest_dir: Optional[str] = None):
+    def retrieve_artifacts(self, src_dir: str, dest_dir: T.Optional[str] = None):
         from glob import glob
 
         print_section('Retrieving build artifacts')
@@ -721,7 +826,7 @@ class OSBase:
                 acount += 1
         print_info('Copied {} files.'.format(acount))
 
-    def _copy_command_script_to_instance_dir(self, instance_dir: str, command_script: str) -> Optional[str]:
+    def _copy_command_script_to_instance_dir(self, instance_dir: str, command_script: str) -> T.Optional[str]:
         '''
         Copy a script from the host to the current instance directory and make it
         executable.
@@ -742,9 +847,18 @@ class OSBase:
 
         return os.path.join('/srv', 'tmp', os.path.basename(host_script))
 
-    def run(self, command, build_dir, artifacts_dir, init_command=None, copy_command=False,
-            header_msg=None, bind_build_dir: Optional[str] = None, allowed: list[str] = None):
-        ''' Run an arbitrary command or script in the container '''
+    def run(
+        self,
+        command,
+        build_dir,
+        artifacts_dir,
+        init_command=None,
+        copy_command=False,
+        header_msg=None,
+        bind_build_dir: T.Optional[str] = None,
+        allowed: list[str] = None,
+    ):
+        '''Run an arbitrary command or script in the container'''
         ensure_root()
 
         if not self._load_existent():
@@ -758,6 +872,7 @@ class OSBase:
         if isinstance(init_command, str):
             if init_command:
                 import shlex
+
                 init_command = shlex.split(init_command)
         init_command = listify(init_command)
         allowed = listify(allowed)
@@ -783,16 +898,17 @@ class OSBase:
                     host_script = init_command[0]
                     init_command[0] = self._copy_command_script_to_instance_dir(instance_dir, host_script)
                     if not init_command[0]:
-                        print_error(('Unable to find initialization script "{}", '
-                                     'can not copy it to the container. Exiting.').format(host_script))
+                        print_error(
+                            (
+                                'Unable to find initialization script "{}", '
+                                'can not copy it to the container. Exiting.'
+                            ).format(host_script)
+                        )
                         return False
 
-                r = nspawn_run_helper_persist(self,
-                                              instance_dir,
-                                              machine_name,
-                                              '--prepare-run',
-                                              '/srv',
-                                              build_uid=self._builder_uid)
+                r = nspawn_run_helper_persist(
+                    self, instance_dir, machine_name, '--prepare-run', '/srv', build_uid=self._builder_uid
+                )
                 if r != 0:
                     print_error('Container setup failed.')
                     return False
@@ -807,19 +923,23 @@ class OSBase:
                 init_nspawn_flags = []
                 if build_dir:
                     if not bind_build_dir:
-                        shutil.copytree(build_dir, os.path.join(instance_dir, 'srv', 'build'), dirs_exist_ok=True)
+                        shutil.copytree(
+                            build_dir, os.path.join(instance_dir, 'srv', 'build'), dirs_exist_ok=True
+                        )
                     else:
                         if bind_build_dir == 'rw':
                             init_nspawn_flags = ['--bind={}:/srv/build/'.format(build_dir)]
                         elif bind_build_dir == 'ro':
                             init_nspawn_flags = ['--bind-ro={}:/srv/build/'.format(build_dir)]
-                r = nspawn_run_persist(self,
-                                       instance_dir,
-                                       machine_name,
-                                       '/srv',
-                                       init_command,
-                                       init_nspawn_flags,
-                                       allowed=filtered_allowed)
+                r = nspawn_run_persist(
+                    self,
+                    instance_dir,
+                    machine_name,
+                    '/srv',
+                    init_command,
+                    init_nspawn_flags,
+                    allowed=filtered_allowed,
+                )
                 if r != 0:
                     return False
 
@@ -840,16 +960,16 @@ class OSBase:
                 host_script = command[0]
                 command[0] = self._copy_command_script_to_instance_dir(instance_dir, host_script)
                 if not command[0]:
-                    print_error(('Unable to find script "{}", can not copy it to the container. '
-                                 'Exiting.').format(host_script))
+                    print_error(
+                        ('Unable to find script "{}", can not copy it to the container. ' 'Exiting.').format(
+                            host_script
+                        )
+                    )
                     return False
 
-            r = nspawn_run_helper_persist(self,
-                                          instance_dir,
-                                          machine_name,
-                                          '--prepare-run',
-                                          '/srv',
-                                          build_uid=self._builder_uid)
+            r = nspawn_run_helper_persist(
+                self, instance_dir, machine_name, '--prepare-run', '/srv', build_uid=self._builder_uid
+            )
             if r != 0:
                 print_error('Container setup failed.')
                 return False
@@ -875,13 +995,9 @@ class OSBase:
                     elif bind_build_dir == 'ro':
                         nspawn_flags.extend(['--bind-ro={}:/srv/build/'.format(build_dir)])
 
-            r = nspawn_run_persist(self,
-                                   instance_dir,
-                                   machine_name,
-                                   chdir,
-                                   command,
-                                   nspawn_flags,
-                                   allowed=allowed)
+            r = nspawn_run_persist(
+                self, instance_dir, machine_name, chdir, command, nspawn_flags, allowed=allowed
+            )
             if r != 0:
                 return False
 
